@@ -1,6 +1,6 @@
 /*
  * Photos - access, organize and share your photos on GNOME
- * Copyright © 2012, 2013 Red Hat, Inc.
+ * Copyright © 2012, 2013, 2014 Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -31,6 +31,7 @@
 #include <gio/gio.h>
 #include <glib.h>
 #include <gtk/gtk.h>
+#include <tracker-sparql.h>
 
 G_BEGIN_DECLS
 
@@ -49,12 +50,9 @@ GIcon           *photos_utils_create_symbolic_icon        (const gchar *name, gi
 
 gboolean         photos_utils_create_thumbnail            (GFile *file, GCancellable *cancellable, GError **error);
 
-const gchar     *photos_utils_dot_dir                     (void);
+GIcon           *photos_utils_get_icon_from_cursor        (TrackerSparqlCursor *cursor);
 
-GdkPixbuf       *photos_utils_embed_image_in_frame        (GdkPixbuf *source_image,
-                                                           const gchar *frame_image_path,
-                                                           GtkBorder *slice_width,
-                                                           GtkBorder *border_width);
+const gchar     *photos_utils_dot_dir                     (void);
 
 GQuark           photos_utils_error_quark                 (void);
 
